@@ -2,8 +2,10 @@
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Poll.pm,v 1.2 2006/01/09 13:24:42 gavin Exp $
+# $Id: Poll.pm,v 1.3 2006/12/13 13:54:17 gavin Exp $
 package Net::EPP::Frame::Command::Poll;
+use Net::EPP::Frame::Command::Poll::Req;
+use Net::EPP::Frame::Command::Poll::Ack;
 use base qw(Net::EPP::Frame::Command);
 use strict;
 
